@@ -51,11 +51,15 @@ exec("from "+prefix+"getProfitAbility import getProfitAbility")  #ยกเล
 exec("from "+prefix+"starfishXfn import getMemberOfIndex")
 
 #from starfishX.starfishXfn import listStockInSector
-exec("from "+prefix+"starfishXfn import listStockInSector")
+# exec("from "+prefix+"starfishXfn import listStockInSector")
 
 #from starfishX.starfishXfn import getFundamentalInSector
-exec("from "+prefix+"starfishXfn import getFundamentalInSector")
-
+#exec("from "+prefix+"starfishXfn import getFundamentalInSector")   fixbug after settrade change webpage
+#version > 0.155538
+exec("from "+prefix+"getFundamentalInSector import getFundamentalInSector") 
+exec("from "+prefix+"getFundamentalInSector import listStockInSector")
+exec("from "+prefix+"getFundamentalInSector import getPriceAndRatioInSector") 
+exec("from "+prefix+"getFundamentalInSector import getRatioAndBalanceSheet") 
 #from starfishXfn import evperebitda #ยกเลิกก่อน
 
 #from starfishX.starfishXfn import MarkowitzProcess
@@ -206,6 +210,6 @@ exec("from "+prefix+"greek import EuropeanCallRolling")
 #exec("from "+prefix+"utilHelpers import HistStockPrice")
  
 
-__version__ = 0.155536  #11 กุมภาพันธ์ 2565 update 0.155536
+__version__ = 0.155538  #11 กุมภาพันธ์ 2565 update 0.155536
 
 __doc__ = """starfishX Version จัดเตรียมข้อมูลสำหรับประมวลผลการลงทุนในตลาดหุ้นไทย """
\ No newline at end of file
