@@ -6,6 +6,9 @@ import numpy as np
 
 
 def getMarketCapWithHist(symbol):
+ '''
+ symbol : str ชื่อย่อของหุ้น
+ '''  
  #ป้องกันพวก &
  headers = {"User-Agent": "Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/58.0.3029.110 Safari/537.36"}   
  mrkCap = np.NAN
@@ -90,9 +93,21 @@ def findMarketCapProcess(symbol):
        #print("Market Cap",symbol,mrkCap)
      indexdata +=1 
      #####################
-    return symbol,np.float(mrkCap)
+
+    #ป้องกัน พวกข้อมูลที่เป็น '-'  
+    try:
+      mrkCap = np.float(mrkCap)  
+    except:
+      mrkCap = np.nan 
+
+    return symbol,mrkCap
 
 def findMarketCap(liststock,withHist=False,progress=True):
+  '''
+  คืนค่ามูลค่าตลาดของบริษัท : liststock เป็น str|list 
+  str ถ้าต้องการคืนค่าครั้งละบริษัท เช่น sx.findMarketCap('aot') และสามารถใช้ withHist=True ได้
+  list ถ้าต้องการคืนค่าครั้งละหลายๆ บริษัท เช่น sx.findMarketCap(['jmart','jmt']) แต่ไม่สามารถใช้ withHist=True ได้
+  ''' 
   if(isinstance(liststock, str) and withHist==False):
     s,m = findMarketCapProcess(liststock)
     return m    
