@@ -34,6 +34,9 @@ def news_api(keyword,contentLen=100,contentShort=True,typeMatch=NewsTypeMatch.an
   file = "news/"+filename
   date = filename.replace("news-","").replace(".txt","")[:-3]
   
+  if('DS_Store' in file):
+       continue 
+      
   with open(file) as f:
    for line in f:
     lineP = line.lower() 
