@@ -13,6 +13,10 @@ from IPython.display import HTML
 
 from urllib.parse import quote 
 
+
+import requests
+ 
+
 pd.set_option('display.max_colwidth',-1)
 
 def filterThai(str_data):
@@ -46,55 +50,83 @@ def make_clickable(link):
     #link = link
     return f'<a target="_blank" href="{link}">{text}</a>'
 
-def getReportR59(dateFrom,dateTo,Company="",report=True):
+def getReportR59(dateFrom,dateTo,Company="",report=True,Viewmore=False):
   '''
   ใช้วันที่เป็น พ.ศ. #DD/MM/YYYY 
   ตัวอย่าง getReportR59(dateFrom="01/01/2563",dateTo="30/05/2563",Company="0000003725") 
+  Company : (string) รหัสของบริษัท จะคืนค่านี้มาจาก getValueCompanyR59 
+  dateFrom : (string) ฟังก์ชันนี้กำหนดค่าเป็น พศ. DD/MM/YYYY
+  dateTo : (string) ฟังก์ชันนี้กำหนดค่าเป็น พศ. DD/MM/YYYY
+  Viewmore : (Boolean) หากกำหนดเป็น True จะคืนค่ามากกว่า 100 รายการได้
 
   หากใช้งานไม่ได้ ทดลองติดตั้งเพิ่มเติมด้วยคำสั่ง
   conda install -c conda-forge geckodriver
   ''' 
-  #dateFrom = "01/01/2563"
-  #dateTo = "10/01/2563"
-  #Company = "0000008180"  
-  #dateFrom="01/01/2563"
-  #dateTo="30/04/2563"
-  #Company="0000028632"
-  os.environ['MOZ_HEADLESS'] = '1'  
-  driver = webdriver.Firefox()  #อาจต้องลง 
-  # Grab the web page
-    
-  driver.get("https://market.sec.or.th/public/idisc/th/r59")
-  #กำหนดค่าใน textbox
-  k = driver.find_element_by_id("BSDateFrom")
-  k.clear()
-  k.send_keys(dateFrom)
-  driver.find_element_by_id("BSDateFrom").get_attribute("value")
-    
-  ### Dateto
-  k = driver.find_element_by_id("BSDateTo")
-  k.clear()
-  k.send_keys(dateTo)
-  driver.find_element_by_id("BSDateTo").get_attribute("value")
-
-  if(Company!=""):
-   ### Select
-   k = Select(driver.find_element_by_id("ctl00_CPH_ddlCompany"))
-   k.select_by_value(Company)
-   #driver.find_element_by_id("BSDateTo").get_attribute("value")
-
-
-  ### หาปุ่ม submit และกด click
-  btn_input = driver.find_element_by_id("ctl00_CPH_btSearch")
-  # Then we'll fake typing into it
-  btn_input.click()  
-
-  ### เริ่ม parser
-  # We can feed that into Beautiful Soup
-  doc = BeautifulSoup(driver.page_source,"html.parser")  
-  rows = doc.find('table', id='gPP09T01')  
-  
+  if(Viewmore==True):
+   d1 = dateFrom.split('/')
+   dateFrom = str(int(d1[2])-543)+d1[1]+d1[0]
    
+   d2 = dateTo.split('/')
+   dateTo = str(int(d2[2])-543)+d2[1]+d2[0]
+
+   url = 'https://market.sec.or.th/public/idisc/th/Viewmore/r59-2?DateType=1&DateFrom='+dateFrom+'&DateTo='+dateTo
+   headers = {"User-Agent": "Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/58.0.3029.110 Safari/537.36"}  
+   r = requests.post(url,headers=headers, timeout=5)
+   soup = BeautifulSoup(r.content, "lxml") 
+   rows = soup.find_all('table',{'table table-striped table-hover'})     
+   rows = rows[0]
+    
+  else:
+   #dateFrom = "01/01/2563"
+   #dateTo = "10/01/2563"
+   #Company = "0000008180"  
+   #dateFrom="01/01/2563"
+   #dateTo="30/04/2563"
+   #Company="0000028632"
+   if 'google.colab' in str(get_ipython()):
+    chrome_options = webdriver.ChromeOptions()
+    chrome_options.add_argument('--headless')
+    chrome_options.add_argument('--no-sandbox')
+    chrome_options.add_argument('--disable-dev-shm-usage')
+    driver = webdriver.Chrome('chromedriver',chrome_options=chrome_options)
+   else:   
+    os.environ['MOZ_HEADLESS'] = '1'  
+    driver = webdriver.Firefox()  #อาจต้องลง 
+   # Grab the web page
+    
+   driver.get("https://market.sec.or.th/public/idisc/th/r59")
+   #กำหนดค่าใน textbox
+   k = driver.find_element_by_id("BSDateFrom")
+   k.clear()
+   k.send_keys(dateFrom)
+   driver.find_element_by_id("BSDateFrom").get_attribute("value")
+    
+   ### Dateto
+   k = driver.find_element_by_id("BSDateTo")
+   k.clear()
+   k.send_keys(dateTo)
+   driver.find_element_by_id("BSDateTo").get_attribute("value")
+
+   if(Company!=""):
+   ### Select
+    k = Select(driver.find_element_by_id("ctl00_CPH_ddlCompany"))
+    k.select_by_value(Company)
+    #driver.find_element_by_id("BSDateTo").get_attribute("value")
+   elif(Company==""):
+    k = Select(driver.find_element_by_id("ctl00_CPH_ddlCompany"))  
+    k.select_by_value("")  
+
+   ### หาปุ่ม submit และกด click
+   btn_input = driver.find_element_by_id("ctl00_CPH_btSearch")
+   # Then we'll fake typing into it
+   btn_input.click()  
+
+   ### เริ่ม parser
+   # We can feed that into Beautiful Soup
+   doc = BeautifulSoup(driver.page_source,"html.parser")  
+   rows = doc.find('table', id='gPP09T01')  
+  
+  ############################################# 
   if("ไม่พบข้อมูล" in str(rows)):
     return 0
     #print(1)
@@ -132,9 +164,19 @@ def getReportR59(dateFrom,dateTo,Company="",report=True):
   df["Company"] = [filterThai(j) for j in df["Company"]]
   #del df['Remark']
   
-  df["Amount"] = df["Amount"].str.replace(",","").astype(float)  
-  df["AvgPrice"] = df["AvgPrice"].str.replace(",","").astype(float)
-  driver.close()  
+  try:
+   df["Amount"] = df["Amount"].str.replace(",","").astype(float) 
+  except:
+   df["Amount"] = df["Amount"].str.replace(",","")
+
+  try: 
+   df["AvgPrice"] = df["AvgPrice"].str.replace(",","").astype(float)
+  except:
+   df["AvgPrice"] = df["AvgPrice"].str.replace(",","")
+
+  
+  if(Viewmore==False):
+   driver.close()  
 
   #เพิ่ม link HTML รายละเอียด
 
@@ -151,7 +193,12 @@ def getReportR59(dateFrom,dateTo,Company="",report=True):
 
 #### แบบรายงาน R246
 def getReportR246(symbolOrName,datefrom,dateto,person=False):
-    
+    '''
+    pl.getReportR246(symbolOrName='',datefrom='2020-10-01',dateto='2020-10-30')
+    symbolOrName : (string) ชื่อหุ้น หากไม่ระบุจะคืนค่าทุกตัวในช่วงวันนั้นๆ
+    datefrom : (string) ระบุเป็นคศ. YY-MM-DD
+    dateto :  (string) ระบุเป็นคศ. YY-MM-DD
+    '''
     ###########
     datefrom = datefrom.replace("-","")
     dateto = dateto.replace("-","")
